from jinja2 import Undefined, Template
import jinja2.ext
from jinja2.lexer import Token

'''
Dont break pageloads because vars arent there!
'''


class SilentUndefined(Undefined):

    def _fail_with_undefined_error(self, *args, **kwargs):
        class EmptyString(str):
            def __call__(self, *args, **kwargs):
                return ''
        return EmptyString()

    __add__ = __radd__ = __mul__ = __rmul__ = __div__ = __rdiv__ = \
    __truediv__ = __rtruediv__ = __floordiv__ = __rfloordiv__ = \
    __mod__ = __rmod__ = __pos__ = __neg__ = __call__ = \
    __getitem__ = __lt__ = __le__ = __gt__ = __ge__ = __int__ = \
    __float__ = __complex__ = __pow__ = __rpow__ = _fail_with_undefined_error


class YAMLEverythingExtension(jinja2.ext.Extension):
    """
    Insert a `|yaml` filter at the end of every variable substitution.

    This will ensure that all injected values are converted to YAML.
    """
    def filter_stream(self, stream):
        # This is based on https://github.com/indico/indico/blob/master/indico/web/flask/templating.py.
        tokens = []
        tokens_name = []
        for token in stream:
            if token.type == 'variable_begin':
                tokens = []
                tokens_name = []
            if token.type == 'variable_end':
                if not('lparen' in tokens and 'pipe' not in tokens):
                    if 'field_name' not in tokens_name:
                        yield Token(token.lineno, 'pipe', '|')
                        yield Token(token.lineno, 'name', 'yaml_filter')
            tokens.append(token.type)
            tokens_name.append(token.value)
            yield token


countries = {
    'AF': 'Afghanistan',
    'OA': 'African Intellectual Property Organization (OAPI)',
    'AL': 'Albania',
    'DZ': 'Algeria',
    'AD': 'Andorra',
    'AO': 'Angola',
    'AI': ['Anguilla', 'british anguilla'],
    'AG': 'Antigua and Barbuda',
    'AR': ['Argentina',
        'Argentine Republic',
        'Republic of Argentine' ],
    'AM': 'Armenia',
    'AW': 'Aruba',
    'AU': ['Australia', 'Commonwealth of Australia', 'federal republic of austria'],
    'AT': ['Austria', 'austrian republic'],
    'AZ': 'Azerbaijan',
    'BS': ['Bahamas','Bahamas Islands', 'Commonwealth of Bahamas', 'the bahamas'],
    'BH': ['Bahrain', 'Kingdom of Bahrain'],
    'BD': 'Bangladesh',
    'BB': 'Barbados',
    'BY': 'Belarus',
    'BE': ['Belgium', 'State of Belgium', 'Kingdom of Belgium'],
    'BZ': 'Belize',
    'BX': 'Benelux',
    'BJ': 'Benin',
    'BM': 'Bermuda',
    'BT': 'Bhutan',
    'BO': 'Bolivia',
    'BQ': ['Bonaire, Sint Eustatius and Saba',
           'Saint Eustatius and Saba'],
    'BA': 'Bosnia and Herzegovina',
    'BW': 'Botswana',
    'BR': 'Brazil',
    'VG': ['British Virgin Islands',
        'British Virgin Isles',
        'Virgin Islands',
        'Virgin Islands, British'],
    'VI': ['United States Virgin Islands', 'Virgin Islands, U.S.'],
    'BN': ['Brunei Darussalam', 'brunei'],
    'BG': 'Bulgaria',
    'HV': 'Burkina Faso',
    'BF': 'Burkina Faso',
    'BI': 'Burundi',
    'KH': 'Cambodia',
    'CM': 'Cameroon',
    'CA': ['Canada', 'Dominion of Canada', 'British Colombia, Canada'],
    'CK': 'Cook Islands',
    'KY': 'Cayman Islands',
    'CF': 'Central African Republic',
    'TD': 'Chad',
    'CC': 'Cocos-keeling Islands',
    'CL': 'Chile',
    'CN': ['China',
        "The People's Republic of China",
        "People's Republic of China",
        'Republic of China'],
    'CO': 'Colombia',
    'KM': 'Comoros',
    'CG': 'Congo',
    'CR': 'Costa Rica',
    'CI': ['C&#xF4;te d\'Ivoire',
           "côte d'ivoire",
           'Ivory Coast'],
    'HR': 'Croatia',
    'CU': ['Cuba', 'Republic of Cuba'],
    'CW': ['Cura&#xE7;ao',
           'Curacao',
           'Curaçao',
           'Curacau'],
    'CY': ['Cyprus', 'northern cyprus'],
    'CZ': 'Czech Republic',
    'CS': ['Czechoslovakia', 'republic of czechoslovakia'],
    'KP': ['Democratic People\'s Republic of Korea', 'north korea'],
    'CD': ['Democratic Republic of the Congo','congo, the democratic republic of the', 'republic of the congo'],
    'DK': ['Denmark', 'Kingdom of Denmark'],
    'DJ': 'Djibouti',
    'DM': 'Dominica',
    'DO': 'Dominican Republic',
    'EC': 'Ecuador',
    'EG': 'Egypt',
    'SV': 'El Salvador',
    'GQ': 'Equatorial Guinea',
    'EE': 'Estonia',
    'ET': 'Ethiopia',
    'ER': 'Eritrea',
    'EH': 'western sahara',
    'EA': ['Eurasian Patent Organization', 'Eurasian Patent Organization (eapo)'],
    'EP': ['European Patent Office', 'eurasian patent organization (eapo)'],
    'EM': ['European Community','European Union', 'European Communities'],
    'FO': 'Faroe Islands',
    'FJ': 'Fiji',
    'FI': 'Finland',
    'FM': ['state of micronesia','Federated States of Micronesia'],
    'FR': ['France',
            'French Republic',
            'republic of france',
            'French'],
    'GA': 'Gabon',
    'GM': 'Gambia',
    'GE': 'Georgia',
    'DE': ['Germany',
            'Federal Republic of Germany',
            'Federal Republic of Western Germany',
            'German Democratic Republic',
            'Eastern Zone of Germany',
            'German Federal Republic',
            'Republic of Germany',
            'Western Germany',
            'West Germany'],
    # 'DT': 'Germany (without the territory that prior to October 3, 1990, constituted the German Democratic Republic)',
    # 'DD': 'Germany (without the territory that prior to October 3, 1990, constituted the Federal Republic of Germany)',
    'GH': 'Ghana',
    'GI': 'Gibraltar',
    'GR': 'Greece',
    'GL': 'Greenland',
    'GD': 'Grenada',
    'GT': 'Guatemala',
    'GG': 'Guernsey',
    'GN': 'Guinea',
    'GW': ['Guinea-Bissau', 'guinea bissau'],
    'GY': 'Guyana',
    'HT': 'Haiti',
    'VA': ['Holy See', 'holy see (vatican city state)'],
    'HN': 'Honduras',
    'HK': ['Hong-Kong',
            'Hong Kong',
            'Hong Kong, China',
            'Colony of Hong Kong'],
    'HU': ['Hungary',"People's Republic of Hungary", "hungarian people's republic"],
    'IS': 'Iceland',
    'IN': ['India',
            'Republic of India',
            'British India',
            'French India'],
    'ID': ['Indonesia',
            'United States of Indonesia',
            'Republic of United States of Indonesia',
            'republic of the united states of indonesia',
            'Republic of Indonesia'],
    'WO': ['International Bureau of the World Intellectual Property Organization (WIPO)',
           'World Intellectual Property Organization (WIPO)'],
    'QO': 'Organization without ST.3 code',
    'IQ': 'Iraq',
    'IE': 'Ireland',
    'IR': ['Islamic Republic of Iran',
           'Iran (Islamic Republic of)',
           'Iran'],
    'IM': 'Isle of Man',
    'IL': 'Israel',
    'IT': ['Italy', 'Republic of Italy'],
    'JM': 'Jamaica',
    'JP': 'Japan',
    'JE': ['Jersey',
           'Jersey Islands',
           'Channel Islands'],
    'JO': 'Jordan',
    'KZ': 'Kazakhstan',
    'KE': 'Kenya',
    'KW': 'Kuwait',
    'KG': 'Kyrgyzstan',
    'LA': ['Lao People\'s Democratic Republic', 'laos'],
    'LV': 'Latvia',
    'LB': 'Lebanon',
    'LS': 'Lesotho',
    'LR': 'Liberia',
    'LY': 'Libya',
    'LI': ['Liechtenstein', 'Principality of Liechtenstein'],
    'LT': 'Lithuania',
    'LU': 'Luxembourg',
    'MO': ['Macao', 'Macau'],
    'MG': 'Madagascar',
    'MP': ['Northern Mariana Islands','Northern Mariana'],
    'MW': 'Malawi',
    'MY': ['Malaysia',
            'State of Malaysia',
            'Federated Malay States',
            'Federation of Malaysia',
            'Malaya',
            'Malayan Union',
            'States of Malaya',
            'Federation of Malaya'],
    'MV': 'Maldives',
    'ML': 'Mali',
    'MT': 'Malta',
    'MH': ['Marshall Islands',
           'Marshal Islands'],
    'MR': 'Mauritania',
    'MU': 'Mauritius',
    'MQ': 'Martinique',
    'MX': 'Mexico',
    'MC': 'Monaco',
    'MN': 'Mongolia',
    'ME': 'Montenegro',
    'MA': 'Morocco',
    'MF': 'Saint Martin',
    'MZ': 'Mozambique',
    'MM': 'Myanmar',
    'NA': 'Namibia',
    'NP': 'Nepal',
    'NL': ['Netherlands',
            'Holland',
            'united kingdom of netherlands',
            'Kingdom of the Netherlands'],
    'AN': ['Netherlands Antilles',
            'Dutch Antilles',
            'West Indies',
            'Dutch East Indies'],
    'NZ': ['New Zealand', 'dominion of new zealand'],
    'NI': 'Nicaragua',
    'NE': 'Niger',
    'NG': ['Nigeria',
           'Federal Republic of Nigeria'],
    'NO': ['Norway', 'Kingdom of Norway'],
    'OM': 'Oman',
    'PK': 'Pakistan',
    'PA': ['Panama', 'Republic of Panama'],
    'PG': 'Papua New Guinea',
    'PY': 'Paraguay',
    'PE': 'Peru',
    'PH': ['Philippines', 'Republic of Philippines', 'philippines islands'],
    'PL': 'Poland',
    'PT': 'Portugal',
    'PR': 'Puerto Rico',
    'PS': 'Palestinian Authority',
    'QA': 'Qatar',
    'KR': ['Republic of Korea',
           'South Korea',
           'Republic of South Korea',
           'Korea'],
    'MD': ['Republic of Moldova', 'moldova'],
    'RO': 'Romania',
    'RU': ['Russian Federation', 'U.S.S.R', 'russia'],
    'RW': 'Rwanda',
    'KN': 'Saint Kitts and Nevis',
    'LC': 'Saint Lucia',
    'VC': 'Saint Vincent and the Grenadines',
    'WS': 'Samoa',
    'SM': ['San Marino', 'republic of san marino'],
    'ST': 'Sao Tome and Principe',
    'SA': 'Saudi Arabia',
    'SN': 'Senegal',
    'RS': ['Serbia','republic of serbia'],
    'YU': 'Serbia and Montenegro',
    'SC': ['Seychelles', 'Republic of Seychelles'],
    'SL': 'Sierra Leone',
    'SG': ['Singapore',
            'Republic of Singapore',
            'Singapore, Straits Settlement',
            'Colony of Singapore',
            'State of Singapore'],
    'SX': 'Sint Maarten (Dutch part)',
    'SK': 'Slovakia',
    'SI': 'Slovenia',
    'SB': 'Solomon Islands',
    'ZA': ['South Africa',
            'Bophuthatswana',
            'union of south africa',
           'Republic of South Africa'],
    'SS': 'South Sudan',
    'SU': 'Soviet Union',
    'ES': 'Spain',
    'LK': ['Sri Lanka', 'Republic of Sri Lanka', 'Ceylon'],
    'SD': 'Sudan',
    'SR': 'Suriname',
    'SO': ['Somalia', 'Somaliland'],
    'SZ': ['Swaziland','Eswatini'],
    'SE': ['Sweden', 'Kingdom of Sweden'],
    'CH': ['Switzerland',
            'Swiss Republic',
            'Republic of Switzerland'],
    'SY': ['Syrian Arab Republic', 'Syria'],
    'TW': ['Taiwan, Province of China',
            'Taiwan',
            'Chinese Taipei',
           'Taiwan, Republic of China',
           'Taiwan (Republic of China)'],
    'TJ': 'Tajikistan',
    'TH': ['Thailand', 'Kingdom of Thailand'],
    'MK': ['North Macedonia',
           'Yogoslavia',
           'macedonia',
           'the former yugoslav rep of macedonia',
           'The former Yugoslav Republic of Macedonia'],
    'CV': 'the Republic of Cabo Verde',
    'TG': 'Togo',
    'TO': 'Tonga',
    'TT': 'Trinidad and Tobago',
    'TN': 'Tunisia',
    'TR': 'Turkey',
    'TM': 'Turkmenistan',
    'TC': ['Turks and Caicos Islands',
            'Turks & Caicos Islands',
            'Turks'],
    'UG': 'Uganda',
    'UA': 'Ukraine',
    'AE': ['United Arab Emirates', 'Dubai'],
    'GB': ['United Kingdom',
           'Scotland',
           'England',
           'Wales',
           'colony of north borneo',
           'united states minor outlying islands',
           'England and Wales',
           'England and Wales',
           'United Kingdom; England and Wales',
           'Scotland',
           'Britain',
           'united kingdom of great britain',
           'Great Britain',
           'Great Britain and Ireland',
           'Republic of Ireland',
           'Northern Ireland'],
    'TL': ['East Timor', 'Timor-Leste'],
    'TV': 'Tuvalu',
    'TZ': ['United Republic of Tanzania',
            'tanzania, united republic of'],
    'US': ['U.S.A.',
           'United States of America',
           'USA'],
    'UY': 'Uruguay',
    'UZ': 'Uzbekistan',
    'VA': ['Holy See Vatican City State', 'holy see (vatican city state)'],
    'VU': ['Vanuatu','New Hebrides'],
    'VE': ['Venezuela','venezuela, bolivarian republic of'],
    'VN': ['Viet Nam', 'Vietnam'],
    'YE': ['Yemen', 'Republic of Yemen'],
    'ZR': 'Zaire',
    'ZM': 'Zambia',
    'ZW': ['Zimbabwe', 'Republic of Zimbabwe'],
    'XK': ['Straits Settlements', 'kosovo'],
    'XV': 'British West Indies',
    'XZ': 'British Indian Ocean Territory'
}
